@@ -13,7 +13,7 @@
 #include "application.h"
 #include "load-graph.h"
 #include "util.h"
-#include "gsm_color_button.h"
+#include "legacy/gsm_color_button.h"
 
 
 void LoadGraph::clear_background()
@@ -64,6 +64,9 @@ void draw_background(LoadGraph *graph) {
     PangoRectangle extents;
     cairo_surface_t *surface;
     GdkRGBA fg;
+    GdkRGBA fg_grid;
+    double const border_alpha = 0.7;
+    double const grid_alpha = border_alpha / 2.0;
 
     num_bars = graph->num_bars();
     graph->graph_dely = (graph->draw_height - 15) / num_bars; /* round to int to avoid AA blur */
@@ -93,13 +96,35 @@ void draw_background(LoadGraph *graph) {
     cairo_translate (cr, FRAME_WIDTH, FRAME_WIDTH);
 
     /* Draw background rectangle */
-    cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
-    cairo_rectangle (cr, graph->indent, 0,
-                     graph->draw_width - graph->rmargin - graph->indent, graph->real_draw_height);
-    cairo_fill(cr);
+    /* When a user uses a dark theme, the hard-coded
+     * white background in GSM is a lone white on the
+     * display, which makes the user unhappy. To fix
+     * this, here we offer the user a chance to set
+     * his favorite background color. */
+    gtk_style_context_save (context);
+
+    /* Here we specify the name of the class. Now in
+     * the theme's CSS we can specify the own colors
+     * for this class. */
+    gtk_style_context_add_class (context, "loadgraph");
+
+    /* And in case the user does not care, we add
+     * classes that usually have a white background. */
+    gtk_style_context_add_class (context, GTK_STYLE_CLASS_PAPER);
+    gtk_style_context_add_class (context, GTK_STYLE_CLASS_ENTRY);
+
+    /* And, as a bonus, the user can choose the color of the grid. */
+    gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &fg_grid);
+
+    /* Why not use the new features of the
+     * GTK instead of cairo_rectangle ?! :) */
+    gtk_render_background (context, cr, graph->indent, 0.0,
+            graph->draw_width - graph->rmargin - graph->indent,
+            graph->real_draw_height);
+
+    gtk_style_context_restore (context);
 
     cairo_set_line_width (cr, 1.0);
-    cairo_set_source_rgb (cr, 0.89, 0.89, 0.89);
     
     for (i = 0; i <= num_bars; ++i) {
         double y;
@@ -115,7 +140,7 @@ void draw_background(LoadGraph *graph) {
         if (graph->type == LOAD_GRAPH_NET) {
             // operation orders matters so it's 0 if i == num_bars
             guint64 rate = graph->net.max - (i * graph->net.max / num_bars);
-            const std::string captionstr(procman::format_network_rate(rate, graph->net.max));
+            const std::string captionstr(procman::format_network_rate(rate));
             caption = g_strdup(captionstr.c_str());
         } else {
             // operation orders matters so it's 0 if i == num_bars
@@ -130,9 +155,11 @@ void draw_background(LoadGraph *graph) {
         g_free(caption);
 
         if (i==0 || i==num_bars)
-          cairo_set_source_rgb (cr, 0.70, 0.71, 0.70);
-        else 
-          cairo_set_source_rgb (cr, 0.89, 0.89, 0.89);
+            fg_grid.alpha = border_alpha;
+        else
+            fg_grid.alpha = grid_alpha;
+
+        gdk_cairo_set_source_rgba (cr, &fg_grid);
         cairo_move_to (cr, graph->indent, i * graph->graph_dely + 0.5);
         cairo_line_to (cr, graph->draw_width - graph->rmargin + 0.5 + 4, i * graph->graph_dely + 0.5);
         cairo_stroke (cr);
@@ -143,11 +170,13 @@ void draw_background(LoadGraph *graph) {
 
     for (unsigned int i = 0; i < 7; i++) {
         double x = (i) * (graph->draw_width - graph->rmargin - graph->indent) / 6;
-        if (i==0 || i==6)
-          cairo_set_source_rgb (cr, 0.70, 0.71, 0.70);
-        else 
-          cairo_set_source_rgb (cr, 0.89, 0.89, 0.89);
 
+        if (i==0 || i==6)
+            fg_grid.alpha = border_alpha;
+        else
+            fg_grid.alpha = grid_alpha;
+
+        gdk_cairo_set_source_rgba (cr, &fg_grid);
         cairo_move_to (cr, (ceil(x) + 0.5) + graph->indent, 0.5);
         cairo_line_to (cr, (ceil(x) + 0.5) + graph->indent, graph->real_draw_height + 4.5);
         cairo_stroke(cr);
@@ -202,17 +231,27 @@ load_graph_configure (GtkWidget *widget,
     return TRUE;
 }
 
+static void force_refresh (LoadGraph * const graph)
+{
+    graph->clear_background();
+    load_graph_queue_draw (graph);
+}
+
+static void
+load_graph_style_updated (GtkWidget *widget,
+                          gpointer data_ptr)
+{
+    LoadGraph * const graph = static_cast<LoadGraph*>(data_ptr);
+    force_refresh (graph);
+}
+
 static gboolean
 load_graph_state_changed (GtkWidget *widget,
                       GtkStateFlags *flags,
                       gpointer data_ptr)
 {
     LoadGraph * const graph = static_cast<LoadGraph*>(data_ptr);
-
-    graph->clear_background();
-
-    load_graph_queue_draw (graph);
-
+    force_refresh (graph);
     return TRUE;
 }
 
@@ -252,7 +291,7 @@ load_graph_draw (GtkWidget *widget,
     cairo_clip(cr);
 
     bool drawStacked = graph->type == LOAD_GRAPH_CPU && GsmApplication::get()->config.draw_stacked;
-    bool drawSmooth = graph->type == LOAD_GRAPH_CPU && GsmApplication::get()->config.draw_smooth;
+    bool drawSmooth = graph->type != LOAD_GRAPH_CPU || GsmApplication::get()->config.draw_smooth;
     for (j = graph->n-1; j >= 0; j--) {
         gdk_cairo_set_source_rgba (cr, &(graph->colors [j]));
         if (drawStacked) {
@@ -266,14 +305,14 @@ load_graph_draw (GtkWidget *widget,
             if (drawSmooth) {
               cairo_curve_to (cr,
                               x_offset - ((i - 0.5f) * graph->graph_delx),
-                              (1.0f - graph->data[i-1][j]) * graph->real_draw_height + 3.5f,
+                              (1.0 - graph->data[i-1][j]) * graph->real_draw_height + 3.5,
                               x_offset - ((i - 0.5f) * graph->graph_delx),
-                              (1.0f - graph->data[i][j]) * graph->real_draw_height + 3.5f,
+                              (1.0 - graph->data[i][j]) * graph->real_draw_height + 3.5,
                               x_offset - (i * graph->graph_delx),
-                              (1.0f - graph->data[i][j]) * graph->real_draw_height + 3.5f);
+                              (1.0 - graph->data[i][j]) * graph->real_draw_height + 3.5);
             } else {
               cairo_line_to (cr, x_offset - (i * graph->graph_delx),
-                              (1.0f - graph->data[i][j]) * graph->real_draw_height + 3.5f);
+                              (1.0 - graph->data[i][j]) * graph->real_draw_height + 3.5);
             }
 
         }
@@ -293,7 +332,7 @@ load_graph_draw (GtkWidget *widget,
 void
 load_graph_reset (LoadGraph *graph)
 {
-    std::fill(graph->data_block.begin(), graph->data_block.end(), -1.0f);
+    std::fill(graph->data_block.begin(), graph->data_block.end(), -1.0);
 }
 
 static void
@@ -410,7 +449,7 @@ get_memory (LoadGraph *graph)
     gtk_widget_set_sensitive (GTK_WIDGET (graph->swap_color_picker), swap.total > 0);
     
     graph->data[0][0] = mempercent;
-    graph->data[0][1] = swap.total>0 ? swappercent : -1.0f;
+    graph->data[0][1] = swap.total>0 ? swappercent : -1.0;
 }
 
 /* Nice Numbers for Graph Labels after Paul Heckbert
@@ -813,6 +852,8 @@ LoadGraph::LoadGraph(guint type)
                       G_CALLBACK (load_graph_destroy), graph);
     g_signal_connect (G_OBJECT(disp), "state-flags-changed",
                       G_CALLBACK (load_graph_state_changed), graph);
+    g_signal_connect (G_OBJECT(disp), "style-updated",
+                      G_CALLBACK (load_graph_style_updated), graph);
 
     gtk_widget_set_events (GTK_WIDGET (disp), GDK_EXPOSURE_MASK);
 
@@ -820,7 +861,7 @@ LoadGraph::LoadGraph(guint type)
 
 
     /* Allocate data in a contiguous block */
-    data_block = std::vector<float>(n * LoadGraph::NUM_POINTS, -1.0f);
+    data_block = std::vector<double>(n * LoadGraph::NUM_POINTS, -1.0);
 
     for (guint i = 0; i < LoadGraph::NUM_POINTS; ++i)
         data[i] = &data_block[0] + i * n;
